@@ -3,8 +3,7 @@
 
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <gtk/gtkwidget.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtk.h>
 #include <panel-applet.h>
 
 G_BEGIN_DECLS
@@ -16,6 +15,8 @@ typedef struct _MultiloadApplet MultiloadApplet;
 typedef struct _LoadGraph LoadGraph;
 typedef void (*LoadGraphDataFunc) (int, int [], LoadGraph *);
 
+#include "netspeed.h"
+
 struct _LoadGraph {
     MultiloadApplet *multiload;
 
@@ -38,7 +39,6 @@ struct _LoadGraph {
     GdkPixmap *pixmap;
     GdkGC *gc;
     int timer_index;
-    GtkTooltips *tooltips;
 
     gint show_frame;
 
@@ -47,6 +47,8 @@ struct _LoadGraph {
     int cpu_initialized;
 
     double loadavg1;
+    NetSpeed *netspeed_in;
+    NetSpeed *netspeed_out;
 
     gboolean visible;
     gboolean tooltip_update;
